@@ -3,9 +3,11 @@ package cli
 import (
 	"fmt"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/ansi"
 	"github.com/jandedobbeleer/oh-my-posh/src/engine"
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/shell"
+	"github.com/jandedobbeleer/oh-my-posh/src/upgrade"
 
 	"github.com/spf13/cobra"
 )
@@ -63,11 +65,15 @@ func runInit(shellName string) {
 	}
 	env.Init()
 	defer env.Close()
+
 	cfg := engine.LoadConfig(env)
+
 	shell.Transient = cfg.TransientPrompt != nil
 	shell.ErrorLine = cfg.ErrorLine != nil || cfg.ValidLine != nil
 	shell.Tooltips = len(cfg.Tooltips) > 0
 	shell.ShellIntegration = cfg.ShellIntegration
+	shell.PromptMark = shellName == shell.FISH && cfg.ITermFeatures != nil && cfg.ITermFeatures.Contains(ansi.PromptMark)
+
 	for i, block := range cfg.Blocks {
 		// only fetch cursor position when relevant
 		if !cfg.DisableCursorPositioning && (i == 0 && block.Newline) {
@@ -77,11 +83,18 @@ func runInit(shellName string) {
 			shell.RPrompt = true
 		}
 	}
+
+	// allow overriding the upgrade notice from the config
+	if cfg.DisableNotice {
+		env.Cache().Set(upgrade.CACHEKEY, "disabled", -1)
+	}
+
 	if printOutput {
 		init := shell.PrintInit(env)
 		fmt.Print(init)
 		return
 	}
+
 	init := shell.Init(env)
 	fmt.Print(init)
 }
